// Author: Torsten.Leitner@email.de
// (c) 2006/2007


#ifndef TARRAYCOMPLEX2D_RT_H_
#define TARRAYCOMPLEX2D_RT_H_


#include <stdio.h>
#include <iostream>
#include <iomanip>
#include <fstream>
#include <string>
#include <math.h>
#include <complex>
#include <vector>
#include <sstream>
#include <fftw3.h>
#include "Definitions.h"
#include "fftw_fft.h"

#include "InAndOut.h"
#include "Constants.h"

using namespace std;


class tArrayComplex2D_rt
{
public:

//constructors
	tArrayComplex2D_rt();
	tArrayComplex2D_rt(int inNr, int inNtw);
	tArrayComplex2D_rt(const int inNr,const double inRmax,const int inNtw,const double inWmax);
//destructors
	virtual ~tArrayComplex2D_rt();
	
//functions

	int init(int inNr, int inNtw);
	int init(int inNr, double inRmax, int inNtw, double inWmax);
	
	int SetCustomOmega(int inNtw, double inwmin, double inwmax);

	int  fft();
	int ifft();
	
	double power(int ir, int jt);
	
	double abs(int ir, int jt);

	Complex at(int ir, int jt);

	double real(int ir, int jt);

	double imag(int ir, int jt);

// output converted from AU to SI ************
	Complex atSI(int ir, int jt);

	double intensity(int ir, int jt);  // [W/cm2]

	double realSI(int ir, int jt);

	double imagSI(int ir, int jt);

	double powerSI(int ir, int jt);

	double absSI(int ir, int jt);

	double radiusSI(int ir);

	double timeSI(int jt);

	double omegaSI(int jt);
// ********************************************	
	
// these are equal ...	
	double phase(int ir, int jt);
	double phi(int ir, int jt);
// ********************************	
	
	
//variables
		
	int Nr;
	int Ntw;
	
	double *radius,dr,rmin,rmax;
	double *time,  dt,tmin,tmax;
	double *omega, dw,wmin,wmax;
		
	Complex **data;
	
private:

//variables
	int   ir,jt;
	class fftw_fft1d fft1d;

//functions
	

};

#endif /*TARRAYCOMPLEX2D_RT_H_*/


